==> qupzilla_1.6.0.orig.tar.gz: qupzilla-1.6.0/src/plugins/StatusBarIcons/translations/es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="36"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Modificar ajustes de cargado de imagenes de manera global y por sitio</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="60"/>
        <source>Current page settings</source>
        <translation>Ajustes de la página actual</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="63"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Deshabilitar el cargado de imágenes (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Habilitar el cargado de imágenes (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="70"/>
        <source>Global settings</source>
        <translation>Ajustes globales</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="72"/>
        <source>Automatically load images</source>
        <translation>Cargar imágenes automaticamente</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Modificar ajustes de JavaScript de manera global y por sitio</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="49"/>
        <source>Current page settings</source>
        <translation>Ajustes de la página actual</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="52"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Deshabilitar JavaScript (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="55"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Habilitar JavaScript (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="59"/>
        <source>Global settings</source>
        <translation>Ajustes globales</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="60"/>
        <source>Manage JavaScript settings</source>
        <translation>Gestionar los ajustes de JavaScript</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="73"/>
        <source>Proxy configuration</source>
        <translation>Configuración de proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="75"/>
        <source>Select proxy</source>
        <translation>Seleccionar proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="89"/>
        <source>Empty</source>
        <translation>Vacío</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="93"/>
        <source>Manage proxies</source>
        <translation>Gestionar proxies</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="106"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Muestra el estado de la red y gestiona el proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Red:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="110"/>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="114"/>
        <source>Offline</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="118"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="124"/>
        <source>System proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="128"/>
        <source>No proxy</source>
        <translation>Sin proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="132"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>PAC (Autoconfiguración de proxy)</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="136"/>
        <source>User defined</source>
        <translation>Definido por el usuario</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Administrador de proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Seleccionar proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>Añadir proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Sin proxies. Puede añadir un proxy haciendo clic en el botón  &lt;b&gt;Añadir&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Todos los cambios se deben guardar con el botón &lt;b&gt;Guardar&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>Nombre del proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>Eliminar el proxy actual</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>¿Está seguro de eliminar el proxy actual?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>No usar proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>Usar un proxy diferente para conecciones https</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;Excepciones&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>No usar en:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>Usar script para configuración automática:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>Configuración de proxy del sistema</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>Archivo de autoconfiguaración de proxy (.pac)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>Configuración manuel</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>Servidor:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Iconos de la barra de estado</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Iconos de la barra de estado&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Estos iconos se mostrarán en la barra de estado:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Icono de imágen</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Icono de JavaScript</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Icono de Red</translation>
    </message>
</context>
</TS>

==> qupzilla-1.6.5.tar.gz: qupzilla-1.6.5/src/plugins/StatusBarIcons/translations/es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="36"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Modificar ajustes de carga de imágenes de manera global y por sitio</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="60"/>
        <source>Current page settings</source>
        <translation>Ajustes de la página actual</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="63"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Deshabilitar cargar imágenes (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Habilitar cargar imágenes (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="70"/>
        <source>Global settings</source>
        <translation>Ajustes globales</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="72"/>
        <source>Automatically load images</source>
        <translation>Cargar imágenes automaticamente</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Modificar ajustes de JavaScript de manera global y por sitio</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="49"/>
        <source>Current page settings</source>
        <translation>Ajustes de la página actual</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="52"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Deshabilitar JavaScript (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="55"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Habilitar JavaScript (temporalmente)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="59"/>
        <source>Global settings</source>
        <translation>Ajustes globales</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="60"/>
        <source>Manage JavaScript settings</source>
        <translation>Gestionar los ajustes de JavaScript</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Proxy configuration</source>
        <translation>Configuración de proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="70"/>
        <source>Select proxy</source>
        <translation>Seleccionar proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Empty</source>
        <translation>Vacío</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="88"/>
        <source>Manage proxies</source>
        <translation>Gestionar proxies</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="101"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Muestra el estado de la red y gestiona el proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Red:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="104"/>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="107"/>
        <source>Offline</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>System proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>No proxy</source>
        <translation>Sin proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="120"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>PAC (Autoconfiguración de proxy)</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="124"/>
        <source>User defined</source>
        <translation>Definido por el usuario</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Administrador de proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Seleccionar proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>Añadir proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Sin proxies. Puede añadir un proxy haciendo clic en el botón  &lt;b&gt;Añadir&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Todos los cambios se deben guardar con el botón &lt;b&gt;Guardar&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>Nombre del proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>Eliminar el proxy actual</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>¿Está seguro de eliminar el proxy actual?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>No usar proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>Usar un proxy diferente para conecciones https</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;Excepciones&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>No usar en:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>Usar script para configuración automática:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>Configuración de proxy del sistema</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>Archivo de autoconfiguaración de proxy (.pac)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>Configuración manuel</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>Servidor:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Iconos de la barra de estado</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Iconos de la barra de estado&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Estos iconos se mostrarán en la barra de estado:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Icono de imágen</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Icono de JavaScript</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Icono de red</translation>
    </message>
</context>
</TS>
